@@ -139,7 +139,7 @@ class EventSub:
         self.__twitch: Twitch = twitch
         self.logger: Logger = getLogger('twitchAPI.eventsub')
         """The logger used for EventSub related log messages"""
-        self.secret: str = ''.join(random.choice(string.ascii_lowercase) for i in range(20))
+        self.secret: str = ''.join(random.choice(string.ascii_lowercase) for _ in range(20))
         """A random secret string. Set this for added security. |default| :code:`A random 20 character long string`"""
         self.wait_for_subscription_confirm: bool = True
         """Set this to false if you don't want to wait for a subscription confirm. |default| :code:`True`"""
@@ -300,7 +300,9 @@ class EventSub:
     # HANDLERS
     # ==================================================================================================================
 
-    async def __handle_default(self, request: 'web.Request'):
+    # noinspection PyUnusedLocal
+    @staticmethod
+    async def __handle_default(request: 'web.Request'):
         return web.Response(text="pyTwitchAPI EventSub")
 
     async def __handle_challenge(self, request: 'web.Request', data: dict):
@@ -375,6 +377,9 @@ class EventSub:
     async def listen_channel_follow(self, broadcaster_user_id: str, callback: CALLBACK_TYPE) -> str:
         """A specified channel receives a follow.
 
+        .. warning:: This subscription is deprecated and will be removed on or soon after the 3rd of August 2023\n
+            Please use :const:`~twitchAPI.eventsub.EventSub.listen_channel_follow_v2()`
+
         For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types#channelfollow
 
         :param broadcaster_user_id: the id of the user you want to listen to
@@ -388,6 +393,31 @@ class EventSub:
         """
         return await self._subscribe('channel.follow', '1', {'broadcaster_user_id': broadcaster_user_id}, callback)
 
+    async def listen_channel_follow_v2(self,
+                                       broadcaster_user_id: str,
+                                       moderator_user_id: str,
+                                       callback: CALLBACK_TYPE) -> str:
+        """A specified channel receives a follow.
+
+        User Authentication with :code:`~twitchAPI.types.AuthScope.MODERATOR_READ_FOLLOWERS` is required.
+
+        For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types#channelfollow
+
+        :param broadcaster_user_id: the id of the user you want to listen to
+        :param moderator_user_id: The ID of the moderator of the channel you want to get follow notifications for.
+        :param callback: function for callback
+        :raises ~twitchAPI.types.EventSubSubscriptionConflict: if a conflict was found with this subscription
+            (e.g. already subscribed to this exact topic)
+        :raises ~twitchAPI.types.EventSubSubscriptionTimeout: if :code:`wait_for_subscription_confirm`
+            is true and the subscription was not fully confirmed in time
+        :raises ~twitchAPI.types.EventSubSubscriptionError: if the subscription failed (see error message for details)
+        :raises ~twitchAPI.types.TwitchBackendException: if the subscription failed due to a twitch backend error
+        """
+        return await self._subscribe('channel.follow',
+                                     '2',
+                                     {'broadcaster_user_id': broadcaster_user_id, 'moderator_user_id': moderator_user_id},
+                                     callback)
+
     async def listen_channel_subscribe(self, broadcaster_user_id: str, callback: CALLBACK_TYPE) -> str:
         """A notification when a specified channel receives a subscriber. This does not include resubscribes.
 
@@ -651,7 +681,8 @@ class EventSub:
                                                                  reward_id: Optional[str] = None) -> str:
         """A viewer has redeemed a custom channel points reward on the specified channel.
 
-        For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types#channelchannel_points_custom_reward_redemptionadd
+        For more information see here:
+        https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types#channelchannel_points_custom_reward_redemptionadd
 
         :param broadcaster_user_id: the id of the user you want to listen to
         :param reward_id: the id of the reward you want to get updates from. |default| :code:`None`
@@ -676,7 +707,8 @@ class EventSub:
                                                                     reward_id: Optional[str] = None) -> str:
         """A redemption of a channel points custom reward has been updated for the specified channel.
 
-        For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types#channelchannel_points_custom_reward_redemptionupdate
+        For more information see here:
+        https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types#channelchannel_points_custom_reward_redemptionupdate
 
         :param broadcaster_user_id: the id of the user you want to listen to
         :param reward_id: the id of the reward you want to get updates from. |default| :code:`None`
@@ -1036,8 +1068,8 @@ class EventSub:
                                                callback: CALLBACK_TYPE) -> str:
         """Sends a notification when the broadcaster activates Shield Mode.
 
-        Requires the :const:`~twitchAPI.types.AuthScope.MODERATOR_READ_SHIELD_MODE` or :const:`~twitchAPI.types.AuthScope.MODERATOR_MANAGE_SHIELD_MODE`
-        auth scope.
+        Requires the :const:`~twitchAPI.types.AuthScope.MODERATOR_READ_SHIELD_MODE` or
+        :const:`~twitchAPI.types.AuthScope.MODERATOR_MANAGE_SHIELD_MODE` auth scope.
 
         For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types/#channelshield_modebegin
 
@@ -1063,8 +1095,8 @@ class EventSub:
                                              callback: CALLBACK_TYPE) -> str:
         """Sends a notification when the broadcaster deactivates Shield Mode.
 
-        Requires the :const:`~twitchAPI.types.AuthScope.MODERATOR_READ_SHIELD_MODE` or :const:`~twitchAPI.types.AuthScope.MODERATOR_MANAGE_SHIELD_MODE`
-        auth scope.
+        Requires the :const:`~twitchAPI.types.AuthScope.MODERATOR_READ_SHIELD_MODE` or
+        :const:`~twitchAPI.types.AuthScope.MODERATOR_MANAGE_SHIELD_MODE` auth scope.
 
         For more information see here: https://dev.twitch.tv/docs/eventsub/eventsub-subscription-types/#channelshield_modeend
 
