@@ -16,6 +16,21 @@ from twitchAPI.types import StatusCode, VideoType, HypeTrainContributionMethod,
 
 T = TypeVar('T')
 
+__all__ = ['TwitchObject', 'IterTwitchObject', 'AsyncIterTwitchObject', 'TwitchUser', 'TwitchUserFollow', 'TwitchUserFollowResult', 'DateRange',
+           'ExtensionAnalytic', 'GameAnalytics', 'CreatorGoal', 'BitsLeaderboardEntry', 'BitsLeaderboard', 'ProductCost', 'ProductData',
+           'ExtensionTransaction', 'ChatSettings', 'CreatedClip', 'Clip', 'CodeStatus', 'Game', 'AutoModStatus', 'BannedUser', 'BanUserResponse',
+           'BlockedTerm', 'Moderator', 'CreateStreamMarkerResponse', 'Stream', 'StreamMarker', 'StreamMarkers', 'GetStreamMarkerResponse',
+           'BroadcasterSubscription', 'BroadcasterSubscriptions', 'UserSubscription', 'StreamTag', 'TeamUser', 'ChannelTeam', 'UserExtension',
+           'ActiveUserExtension', 'UserActiveExtensions', 'VideoMutedSegments', 'Video', 'ChannelInformation', 'SearchChannelResult',
+           'SearchCategoryResult', 'StartCommercialResult', 'Cheermote', 'GetCheermotesResponse', 'HypeTrainContribution', 'HypeTrainEventData',
+           'HypeTrainEvent', 'DropsEntitlement', 'MaxPerStreamSetting', 'MaxPerUserPerStreamSetting', 'GlobalCooldownSetting', 'CustomReward',
+           'PartialCustomReward', 'CustomRewardRedemption', 'ChannelEditor', 'BlockListEntry', 'PollChoice', 'Poll', 'Predictor', 'PredictionOutcome',
+           'Prediction', 'RaidStartResult', 'ChatBadgeVersion', 'ChatBadge', 'Emote', 'GetEmotesResponse', 'EventSubSubscription',
+           'GetEventSubSubscriptionResult', 'StreamCategory', 'ChannelStreamScheduleSegment', 'StreamVacation', 'ChannelStreamSchedule',
+           'ChannelVIP', 'UserChatColor', 'Artist', 'Album', 'Soundtrack', 'TrackSource', 'CurrentSoundtrack', 'Playlist', 'Chatter',
+           'GetChattersResponse', 'ShieldModeStatus', 'CharityAmount', 'CharityCampaign', 'CharityCampaignDonation', 'AutoModSettings',
+           'ChannelFollower', 'ChannelFollowersResult', 'FollowedChannel', 'FollowedChannelsResult']
+
 
 class TwitchObject:
     """
@@ -171,10 +186,7 @@ class AsyncIterTwitchObject(TwitchObject, Generic[T]):
             raise StopAsyncIteration()
         _url = build_url(self._data['url'], self._data['param'], remove_none=True, split_lists=self._data['split'])
         async with ClientSession() as session:
-            if self._data['body'] is None:
-                response = await self._data['req'](session, _url, self._data['auth_t'], self._data['auth_s'])
-            else:
-                response = await self._data['req'](session, _url, self._data['auth_t'], self._data['auth_s'], body=self._data['body'])
+            response = await self._data['req'](session, _url, self._data['auth_t'], self._data['auth_s'], self._data['body'])
             _data = await response.json()
         _after = _data.get('pagination', {}).get('cursor')
         self._data['param']['after'] = _after
@@ -222,6 +234,30 @@ class TwitchUserFollowResult(AsyncIterTwitchObject[TwitchUserFollow]):
     data: List[TwitchUserFollow]
 
 
+class ChannelFollower(TwitchObject):
+    followed_at: datetime
+    user_id: str
+    user_name: str
+    user_login: str
+
+
+class ChannelFollowersResult(AsyncIterTwitchObject[ChannelFollower]):
+    total: int
+    data: List[ChannelFollower]
+
+
+class FollowedChannel(TwitchObject):
+    broadcaster_id: str
+    broadcaster_login: str
+    broadcaster_name: str
+    followed_at: datetime
+
+
+class FollowedChannelsResult(AsyncIterTwitchObject[FollowedChannel]):
+    total: int
+    data: List[FollowedChannel]
+
+
 class DateRange(TwitchObject):
     ended_at: datetime
     started_at: datetime
